@@ -8,4 +8,6 @@
  */
 #include "compat.hxx"
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
